@@ -30,13 +30,13 @@
 #include <assert.h>
 
 #include "ioutils.h"
-#include "fileutils.h"
+//#include "fileutils.h" //# Modified by Robert Lancaster for the StellarSolver Internal Library, removed includes
 #include "bl.h"
 #include "an-bool.h"
 #include "solver.h"
 #include "math.h"
 #include "fitsioutils.h"
-#include "blindutils.h"
+//#include "blindutils.h" //# Modified by Robert Lancaster for the StellarSolver Internal Library, removed includes
 #include "os-features.h"
 #include "blind.h"
 #include "log.h"
@@ -46,7 +46,7 @@
 #include "tic.h"
 #include "healpix.h"
 #include "sip-utils.h"
-#include "multiindex.h"
+//#include "multiindex.h" //# Modified by Robert Lancaster for the StellarSolver Internal Library, removed includes
 
 void engine_add_search_path(engine_t* engine, const char* path) {
     sl_append(engine->index_paths, path);
@@ -93,7 +93,7 @@ int engine_autoindex_search_paths(engine_t* engine) {
             struct dirent* de;
             char* name;
             char* fullpath;
-            char* err;
+            //char* err; //# Modified by Robert Lancaster for the StellarSolver Internal Library, this is not used
             anbool ok;
             errno = 0;
             de = readdir(dir);
@@ -222,7 +222,7 @@ static void add_index_to_blind(engine_t* engine, blind_t* bp,
         blind_add_index(bp, index->indexname);
     }
 }
-
+/* //# Modified by Robert Lancaster for the StellarSolver Internal Library, these functions are not used
 int engine_parse_config_file(engine_t* engine, const char* fn) {
     FILE* fconf;
     int rtn;
@@ -387,7 +387,9 @@ int engine_parse_config_file_stream(engine_t* engine, FILE* fconf) {
     sl_free2(mindices);
     return rtn;
 }
+*/
 
+/* //# Modified by Robert Lancaster for the StellarSolver Internal Library, this function is not used, we make our jobs
 static job_t* job_new() {
     job_t* job = calloc(1, sizeof(job_t));
     if (!job) {
@@ -398,6 +400,7 @@ static job_t* job_new() {
     job->depths = il_new(8);
     return job;
 }
+*/
 
 void job_free(job_t* job) {
     if (!job)
@@ -423,9 +426,10 @@ int engine_run_job(engine_t* engine, job_t* job) {
     double app_max_default;
     anbool solved = FALSE;
 
-    if (blind_is_run_obsolete(bp, sp)) {
-        goto finish;
-    }
+    //# Modified by Robert Lancaster for the StellarSolver Internal Library
+    //if (blind_is_run_obsolete(bp, sp)) {
+    //    goto finish;
+    //}
 
     app_min_default = deg2arcsec(engine->minwidth) / job_imagew(job);
     app_max_default = deg2arcsec(engine->maxwidth) / job_imagew(job);
@@ -537,10 +541,11 @@ int engine_run_job(engine_t* engine, job_t* job) {
             //blind_clear_indexes(bp); //Repetitive?
             solver_clear_indexes(sp);
 
-            if (blind_is_run_obsolete(bp, sp)) {
-                solved = TRUE;
-                break;
-            }
+            //# Modified by Robert Lancaster for the StellarSolver Internal Library
+            //if (blind_is_run_obsolete(bp, sp)) {
+            //    solved = TRUE;
+            //    break;
+            //}
         }
         if (solved)
             break;
@@ -551,13 +556,13 @@ int engine_run_job(engine_t* engine, job_t* job) {
     logverb("RA,Dec constraints: %i\n", sp->num_radec_skipped);
     logverb("AB scale constraints: %i\n", sp->num_abscale_skipped);
 
- finish:
+ //finish: //# Modified by Robert Lancaster for the StellarSolver Internal Library, this label is not used anymore
     //# Modified by Robert Lancaster for the StellarSolver Internal Library, we will clean these up back in StellarSolver.cpp
     //solver_cleanup(sp);
     //blind_cleanup(bp);
     return 0;
 }
-
+/* //# Modified by Robert Lancaster for the StellarSolver Internal Library, this function is not used
 static void parse_sip_coeffs(const qfits_header* hdr, const char* prefix, sip_t* wcs) {
     char key[64];
     int order, i, j;
@@ -911,7 +916,7 @@ static anbool parse_job_from_qfits_header(const qfits_header* hdr, job_t* job) {
  bailout:
     return FALSE;
 }
-
+*/
 
 
 engine_t* engine_new() {
@@ -919,7 +924,7 @@ engine_t* engine_new() {
     engine->index_paths = sl_new(10);
     engine->indexes = pl_new(16);
     engine->free_indexes = pl_new(16);
-    engine->free_mindexes = pl_new(16);
+    //engine->free_mindexes = pl_new(16); //# Modified by Robert Lancaster for the StellarSolver Internal Library
     engine->ismallest = il_new(4);
     engine->ibiggest = il_new(4);
     engine->default_depths = il_new(4);
@@ -944,6 +949,7 @@ void engine_free(engine_t* engine) {
         }
         pl_free(engine->free_indexes);
     }
+    /**
     if (engine->free_mindexes) {
         for (i=0; i<pl_size(engine->free_mindexes); i++) {
             multiindex_t* mi = pl_get(engine->free_mindexes, i);
@@ -951,6 +957,7 @@ void engine_free(engine_t* engine) {
         }
         pl_free(engine->free_mindexes);
     }
+    **/
     pl_free(engine->indexes);
     if (engine->ismallest)
         il_free(engine->ismallest);
@@ -963,6 +970,8 @@ void engine_free(engine_t* engine) {
     free(engine);
 }
 
+/* //# Modified by Robert Lancaster for the StellarSolver Internal Library since we aren't using any files in the internal library
+
 job_t* engine_read_job_file(engine_t* engine, const char* jobfn) {
     qfits_header* hdr;
     job_t* job;
@@ -1098,4 +1107,5 @@ int job_set_output_base_dir(job_t* job, const char* dir) {
     }
     return 0;
 }
+*/
 
