@@ -2,7 +2,9 @@
  # This file is part of the Astrometry.net suite.
  # Licensed under a 3-clause BSD style license - see LICENSE
  */
-
+#ifdef __GNUC__ //# Modified by Robert Lancaster for the StellarSolver Internal Library
+#define __STDC_WANT_LIB_EXT2__ 1
+#endif
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -278,7 +280,7 @@ void bl_remove_index_range(bl* list, size_t start, size_t length) {
     }
 
     // begin by removing any indices that are at the end of a block.
-    if (start > nskipped) {
+    if (node && start > nskipped) { //# Modified by Robert Lancaster for the StellarSolver Internal Library to resolve warning
         // we're not removing everything at this node.
         size_t istart;
         size_t n;
@@ -311,7 +313,7 @@ void bl_remove_index_range(bl* list, size_t start, size_t length) {
     for (;;) {
         size_t n;
         bl_node* todelete;
-        if (length == 0 || length < node->N)
+        if (length == 0 || !node || length < node->N) //# Modified by Robert Lancaster for the StellarSolver Internal Library to resolve warning
             break;
         // we're skipping this whole block.
         n = node->N;
@@ -409,7 +411,8 @@ static void bl_append_node(bl* list, bl_node* node) {
         list->head = node;
         list->tail = node;
     } else {
-        list->tail->next = node;
+        if(list->tail) //# Modified by Robert Lancaster for the StellarSolver Internal Library to resolve warning
+            list->tail->next = node;
         list->tail = node;
     }
     list->N += node->N;
@@ -423,6 +426,8 @@ static void bl_append_node(bl* list, bl_node* node) {
  */
 void* bl_node_append(bl* list, bl_node* node, const void* data) {
     void* dest;
+    if(!node) //# Modified by Robert Lancaster for the StellarSolver Internal Library to resolve warning
+        return 0;
     if (node->N == list->blocksize) {
         // create a new node and insert it after the current node.
         bl_node* newnode;
@@ -721,8 +726,8 @@ int bl_check_consistency(bl* list) {
     if (!list->tail)
         nnull++;
     if (nnull == 1) {
-        fprintf(stderr, "bl_check_consistency: head is %p, and tail is %p.\n",
-                list->head, list->tail);
+        debug("bl_check_consistency: head is %p, and tail is %p.\n",
+                list->head, list->tail); //# Modified by Robert Lancaster for the StellarSolver Internal Library for logging
         return 1;
     }
 
@@ -739,16 +744,16 @@ int bl_check_consistency(bl* list) {
         }
     }
     if (!tailok) {
-        fprintf(stderr, "bl_check_consistency: tail pointer is wrong.\n");
+        debug("bl_check_consistency: tail pointer is wrong.\n"); //# Modified by Robert Lancaster for the StellarSolver Internal Library for logging
         return 1;
     }
     if (nempty) {
-        fprintf(stderr, "bl_check_consistency: %i empty blocks.\n", nempty);
+        debug("bl_check_consistency: %i empty blocks.\n", nempty); //# Modified by Robert Lancaster for the StellarSolver Internal Library for logging
         return 1;
     }
     if (N != list->N) {
-        fprintf(stderr, "bl_check_consistency: list->N is %zu, but sum of blocks is %zu.\n",
-                list->N, N);
+        debug("bl_check_consistency: list->N is %zu, but sum of blocks is %zu.\n",
+                list->N, N); //# Modified by Robert Lancaster for the StellarSolver Internal Library for logging
         return 1;
     }
     return 0;
@@ -780,7 +785,7 @@ int bl_check_sorted(bl* list,
         }
     }
     if (nbad) {
-        fprintf(stderr, "bl_check_sorted: %zu are out of order.\n", nbad);
+        debug("bl_check_sorted: %zu are out of order.\n", nbad); //# Modified by Robert Lancaster for the StellarSolver Internal Library for logging
         return 1;
     }
     return 0;
@@ -1012,7 +1017,8 @@ void sl_append_array(sl* list, const char**strings, size_t n) {
 }
 
 void sl_append_nocopy(sl* list, const char* data) {
-    pl_append(list, data);
+    if(data && list) //# Modified by Robert Lancaster for the StellarSolver Internal Library to resolve warning
+        pl_append(list, data);
 }
 
 char* sl_push(sl* list, const char* data) {
@@ -1208,35 +1214,6 @@ char* sl_appendf(sl* list, const char* format, ...) {
     return str;
 }
 
-#ifdef _WIN32 //# Modified by Robert Lancaster for the StellarSolver Internal Library
-//From http://asprintf.insanecoding.org
-#define insane_free(ptr) { free(ptr); ptr = 0; }
-#include <stdio.h>
-#include <stdlib.h>
-#include <limits.h>
-int vasprintf(char **strp, const char *fmt, va_list ap)
-{
-  int r = -1, size = _vscprintf(fmt, ap);
-
-  if ((size >= 0) && (size < INT_MAX))
-  {
-    *strp = (char *)malloc(size+1); //+1 for null
-    if (*strp)
-    {
-      r = vsnprintf(*strp, size+1, fmt, ap);  //+1 for null
-      if ((r < 0) || (r > size))
-      {
-        insane_free(*strp);
-        r = -1;
-      }
-    }
-  }
-  else { *strp = 0; }
-
-  return(r);
-}
-#endif
-
 char* sl_appendvf(sl* list, const char* format, va_list va) {
     char* str;
     if (vasprintf(&str, format, va) == -1)
