@@ -2,6 +2,9 @@
  # This file is part of the Astrometry.net suite.
  # Licensed under a 3-clause BSD style license - see LICENSE
  */
+#ifdef __GNUC__ //# Modified by Robert Lancaster for the StellarSolver Internal Library
+#define __STDC_WANT_LIB_EXT2__ 1
+#endif
 #include <stdio.h>
 #include <string.h>
 #include <stdint.h>
@@ -20,7 +23,7 @@
 #include "fitsioutils.h"
 #include "ioutils.h"
 #include "keywords.h"
-#include "an-endian.h"
+//#include "an-endian.h" //# Modified by Robert Lancaster for the StellarSolver Internal Library
 #include "errors.h"
 #include "log.h"
 #include "errors.h"
@@ -303,21 +306,21 @@ double fits_get_double_val(const qfits_table* table, int column,
         memcpy(&fval, cdata, sizeof(fval));
         //Note: This is not what we want to do, but this function doesn't work right now
         //But I don't think it is used by the solver either.
-#ifndef _MSC_VER //# Modified by Robert Lancaster for the StellarSolver Internal Library
+/** //# Modified by Robert Lancaster for the StellarSolver Internal Library
         v32_ntoh(&fval);
-#endif
+**/
         dval = fval;
         return fval;
     } else if (table->col[column].atom_type == TFITS_BIN_TYPE_D) {
         memcpy(&dval, cdata, sizeof(dval));
         //Note: This is not what we want to do, but this function doesn't work right now
         //But I don't think it is used by the solver either.
-#ifndef _MSC_VER //# Modified by Robert Lancaster for the StellarSolver Internal Library
+/** //# Modified by Robert Lancaster for the StellarSolver Internal Library
         v64_ntoh(&dval);
-#endif
+**/
         return dval;
     } else {
-        fprintf(stderr, "Invalid column type %i.\n", table->col[column].atom_type);
+        debug("Invalid column type %i.\n", table->col[column].atom_type); //# Modified by Robert Lancaster for the StellarSolver Internal Library for logging
     }
     return HUGE_VAL;
 }
@@ -701,7 +704,7 @@ static int add_long_line(qfits_header* hdr, const char* keyword, const char* ind
     int indlen = (indent ? strlen(indent) : 0);
     len = vasprintf(&origstr, format, lst);
     if (len == -1) {
-        fprintf(stderr, "vasprintf failed: %s\n", strerror(errno));
+        debug("vasprintf failed: %s\n", strerror(errno)); //# Modified by Robert Lancaster for the StellarSolver Internal Library for logging
         return -1;
     }
     str = origstr;
@@ -874,7 +877,7 @@ int fits_add_column(qfits_table* table, int column, tfits_type type,
 
     atomsize = fits_get_atom_size(type);
     if (atomsize == -1) {
-        fprintf(stderr, "Unknown atom size for type %i.\n", type);
+        debug("Unknown atom size for type %i.\n", type); //# Modified by Robert Lancaster for the StellarSolver Internal Library for logging
         return -1;
     }
     if (type == TFITS_BIN_TYPE_X)
@@ -905,12 +908,12 @@ int fits_write_data_D(FILE* fid, double value, anbool flip) {
     assert(sizeof(double) == 8);
     //Note: This is not what we want to do, but this function doesn't work right now
     //But I don't think it is used by the solver either.
-#ifndef _MSC_VER //# Modified by Robert Lancaster for the StellarSolver Internal Library
+/** //# Modified by Robert Lancaster for the StellarSolver Internal Library
     if (flip)
         v64_hton(&value);
-#endif
+**/
     if (fwrite(&value, 8, 1, fid) != 1) {
-        fprintf(stderr, "Failed to write a double to FITS file: %s\n", strerror(errno));
+        debug("Failed to write a double to FITS file: %s\n", strerror(errno)); //# Modified by Robert Lancaster for the StellarSolver Internal Library for logging
         return -1;
     }
     return 0;
@@ -920,12 +923,12 @@ int fits_write_data_E(FILE* fid, float value, anbool flip) {
     assert(sizeof(float) == 4);
     //Note: This is not what we want to do, but this function doesn't work right now
     //But I don't think it is used by the solver either.
-#ifndef _MSC_VER //# Modified by Robert Lancaster for the StellarSolver Internal Library
+/** //# Modified by Robert Lancaster for the StellarSolver Internal Library
     if (flip)
         v32_hton(&value);
-#endif
+**/
     if (fwrite(&value, 4, 1, fid) != 1) {
-        fprintf(stderr, "Failed to write a float to FITS file: %s\n", strerror(errno));
+        debug("Failed to write a float to FITS file: %s\n", strerror(errno)); //# Modified by Robert Lancaster for the StellarSolver Internal Library for logging
         return -1;
     }
     return 0;
@@ -933,7 +936,7 @@ int fits_write_data_E(FILE* fid, float value, anbool flip) {
 
 int fits_write_data_B(FILE* fid, uint8_t value) {
     if (fwrite(&value, 1, 1, fid) != 1) {
-        fprintf(stderr, "Failed to write a bit array to FITS file: %s\n", strerror(errno));
+        debug("Failed to write a bit array to FITS file: %s\n", strerror(errno)); //# Modified by Robert Lancaster for the StellarSolver Internal Library for logging
         return -1;
     }
     return 0;
@@ -954,12 +957,12 @@ int fits_write_data_X(FILE* fid, unsigned char value) {
 int fits_write_data_I(FILE* fid, int16_t value, anbool flip) {
     //Note: This is not what we want to do, but this function doesn't work right now
     //But I don't think it is used by the solver either.
-#ifndef _MSC_VER //# Modified by Robert Lancaster for the StellarSolver Internal Library
+/** //# Modified by Robert Lancaster for the StellarSolver Internal Library
     if (flip)
         v16_hton(&value);
-#endif
+**/
     if (fwrite(&value, 2, 1, fid) != 1) {
-        fprintf(stderr, "Failed to write a short to FITS file: %s\n", strerror(errno));
+        debug("Failed to write a short to FITS file: %s\n", strerror(errno)); //# Modified by Robert Lancaster for the StellarSolver Internal Library for logging
         return -1;
     }
     return 0;
@@ -968,12 +971,12 @@ int fits_write_data_I(FILE* fid, int16_t value, anbool flip) {
 int fits_write_data_J(FILE* fid, int32_t value, anbool flip) {
     //Note: This is not what we want to do, but this function doesn't work right now
     //But I don't think it is used by the solver either.
-#ifndef _MSC_VER //# Modified by Robert Lancaster for the StellarSolver Internal Library
+/** //# Modified by Robert Lancaster for the StellarSolver Internal Library
     if (flip)
         v32_hton(&value);
-#endif
+**/
     if (fwrite(&value, 4, 1, fid) != 1) {
-        fprintf(stderr, "Failed to write an int to FITS file: %s\n", strerror(errno));
+        debug("Failed to write an int to FITS file: %s\n", strerror(errno)); //# Modified by Robert Lancaster for the StellarSolver Internal Library for logging
         return -1;
     }
     return 0;
@@ -982,12 +985,11 @@ int fits_write_data_J(FILE* fid, int32_t value, anbool flip) {
 int fits_write_data_K(FILE* fid, int64_t value, anbool flip) {
     //Note: This is not what we want to do, but this function doesn't work right now
     //But I don't think it is used by the solver either.
-#ifndef _MSC_VER //# Modified by Robert Lancaster for the StellarSolver Internal Library
+/** //# Modified by Robert Lancaster for the StellarSolver Internal Library
     if (flip)
-        v64_hton(&value);
-#endif
+**/
     if (fwrite(&value, 8, 1, fid) != 1) {
-        fprintf(stderr, "Failed to write an int64 to FITS file: %s\n", strerror(errno));
+        debug("Failed to write an int64 to FITS file: %s\n", strerror(errno)); //# Modified by Robert Lancaster for the StellarSolver Internal Library for logging
         return -1;
     }
     return 0;
@@ -1001,8 +1003,8 @@ int fits_write_data_array(FILE* fid, const void* vvalue, tfits_type type,
 
     if (pvalue == NULL) {
         if (fseeko(fid, fits_get_atom_size(type) * N, SEEK_CUR)) {
-            fprintf(stderr, "Failed to skip %i bytes in fits_write_data_array: %s\n",
-                    fits_get_atom_size(type) * N, strerror(errno));
+            debug("Failed to skip %i bytes in fits_write_data_array: %s\n",
+                    fits_get_atom_size(type) * N, strerror(errno)); //# Modified by Robert Lancaster for the StellarSolver Internal Library for logging
             return -1;
         }
         return 0;
@@ -1047,7 +1049,7 @@ int fits_write_data_array(FILE* fid, const void* vvalue, tfits_type type,
             pvalue += sizeof(unsigned char);
             break;
         default:
-            fprintf(stderr, "fitsioutils: fits_write_data: unknown data type %i.\n", type);
+            debug("fitsioutils: fits_write_data: unknown data type %i.\n", type); //# Modified by Robert Lancaster for the StellarSolver Internal Library for logging
             rtn = -1;
             break;
         }
@@ -1213,8 +1215,8 @@ int fits_check_uint_size(const qfits_header* header) {
     int uintsz;
     uintsz = qfits_header_getint(header, "UINT_SZ", -1);
     if (sizeof(uint) != uintsz) {
-        fprintf(stderr, "File was written with sizeof(uint)=%i, but currently sizeof(uint)=%u.\n",
-                uintsz, (uint)sizeof(uint));
+        debug("File was written with sizeof(uint)=%i, but currently sizeof(uint)=%u.\n",
+                uintsz, (uint)sizeof(uint)); //# Modified by Robert Lancaster for the StellarSolver Internal Library for logging
         return -1;
     }
     return 0;
@@ -1224,8 +1226,8 @@ int fits_check_double_size(const qfits_header* header) {
     int doublesz;
     doublesz = qfits_header_getint(header, "DUBL_SZ", -1);
     if (sizeof(double) != doublesz) {
-        fprintf(stderr, "File was written with sizeof(double)=%i, but currently sizeof(double)=%u.\n",
-                doublesz, (uint)sizeof(double));
+        debug("File was written with sizeof(double)=%i, but currently sizeof(double)=%u.\n",
+                doublesz, (uint)sizeof(double)); //# Modified by Robert Lancaster for the StellarSolver Internal Library for logging
         return -1;
     }
     return 0;
@@ -1246,7 +1248,7 @@ int fits_check_endian(const qfits_header* header) {
 
     localstr = fits_get_endian_string();
     if (strcmp(filestr, localstr)) {
-        fprintf(stderr, "File was written with endianness %s, this machine has endianness %s.\n", filestr, localstr);
+        debug("File was written with endianness %s, this machine has endianness %s.\n", filestr, localstr); //# Modified by Robert Lancaster for the StellarSolver Internal Library for logging
         return -1;
     }
     return 0;
