@@ -5,6 +5,8 @@
     License as published by the Free Software Foundation; either
     version 2 of the License, or (at your option) any later version.
 */
+#include <QApplication>
+#include <QSettings>
 #if defined(__APPLE__)
 #include <sys/sysctl.h>
 #elif defined(_WIN32)
@@ -12,13 +14,13 @@
 #else //Linux
 #include <QProcess>
 #endif
+#include "externalextractorsolver.h"
 
 #include "stellarsolver.h"
 #include "extractorsolver.h"
-#include "externalextractorsolver.h"
+
 #include "onlinesolver.h"
-#include <QApplication>
-#include <QSettings>
+
 
 using namespace SSolver;
 
@@ -139,7 +141,7 @@ ExtractorSolver* StellarSolver::createExtractorSolver()
         solver->setSearchScale(m_ScaleLow, m_ScaleHigh, m_ScaleUnit);
     if(m_UsePosition)
         solver->setSearchPositionInDegrees(m_SearchRA, m_SearchDE);
-    if(m_SSLogLevel != LOG_OFF)
+    if(m_AstrometryLogLevel != SSolver::LOG_NONE || m_SSLogLevel != SSolver::LOG_OFF)
         connect(solver, &ExtractorSolver::logOutput, this, &StellarSolver::logOutput);
 
     return solver;
@@ -150,6 +152,17 @@ ExternalProgramPaths StellarSolver::getDefaultExternalPaths(ComputerSystemType s
     return ExternalExtractorSolver::getDefaultExternalPaths(system);
 };
 
+ExternalProgramPaths StellarSolver::getDefaultExternalPaths()
+{
+#if defined(Q_OS_MACOS)
+    return getDefaultExternalPaths(MAC_HOMEBREW);
+#elif defined(Q_OS_LINUX)
+    return getDefaultExternalPaths(LINUX_DEFAULT);
+#else //Windows
+    return getDefaultExternalPaths(WIN_ANSVR);
+#endif
+}
+
 QStringList StellarSolver::getIndexFiles(const QStringList &directoryList, int indexToUse, int healpixToUse)
 {
     QStringList indexFileList;
@@ -316,9 +329,16 @@ bool StellarSolver::checkParameters()
 {
     if(m_ImageBuffer == nullptr)
     {
-        emit logOutput("The image buffer is not loaded, please load an image before processing it");
+        emit logOutput("The image buffer is not loaded, please load an image before processing it.");
         return false;
     }
+    #if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        if(params.partition == true)
+        {
+            emit logOutput("There is a crash sometimes on QT6 when using partitioning. You are using QT6, so I am disabling partitioning to prevent a crash.");
+            params.partition = false;
+        }
+    #endif
 
     if(m_ProcessType == SOLVE && m_SolverType == SOLVER_WATNEYASTROMETRY && (m_Statistics.dataType == SEP_TFLOAT || m_Statistics.dataType == SEP_TDOUBLE))
     {
@@ -438,7 +458,17 @@ void StellarSolver::parallelSolve()
             double high = minScale + scaleConst * pow(thread + 1, 2);
             ExtractorSolver *solver = m_ExtractorSolver->spawnChildSolver(thread);
             connect(solver, &ExtractorSolver::finished, this, &StellarSolver::finishParallelSolve);
-            solver->setSearchScale(low, high, units);
+            if (m_ProcessType == SOLVE && m_SolverType == SOLVER_STELLARSOLVER &&
+                m_ExtractorSolver->m_ActiveParameters.downsample != 1 &&
+                m_ExtractorSolver->scaleunit == ARCSEC_PER_PIX)
+            {
+                // The main solver downsamples and accouts for this in the search scale
+                // but the spawned solvers also need that accounting.
+                double d = m_ExtractorSolver->m_ActiveParameters.downsample;
+                solver->setSearchScale(low*d, high*d, units);
+            }
+            else
+                solver->setSearchScale(low, high, units);
             parallelSolvers.append(solver);
             if(m_SSLogLevel != LOG_OFF)
                 emit logOutput(QString("Solver # %1, Low %2, High %3 %4").arg(parallelSolvers.count()).arg(low).arg(high).arg(
@@ -551,6 +581,11 @@ void StellarSolver::finishParallelSolve(int success)
             if(solver != reportingSolver && solver->isRunning())
                 solver->abort();
         }
+        if(m_AstrometryLogLevel != SSolver::LOG_NONE || m_SSLogLevel != SSolver::LOG_OFF)
+        {
+            for(auto solver : parallelSolvers)
+                disconnect(solver, &ExtractorSolver::logOutput, m_ExtractorSolver.data(), &ExtractorSolver::logOutput);
+        }
         if(m_SSLogLevel != LOG_OFF)
         {
             emit logOutput(QString("Successfully solved with child solver: %1").arg(whichSolver(reportingSolver)));
@@ -577,6 +612,9 @@ void StellarSolver::finishParallelSolve(int success)
     }
     else
     {
+        disconnect(reportingSolver, &ExtractorSolver::finished, this, &StellarSolver::finishParallelSolve);
+        if(m_AstrometryLogLevel != SSolver::LOG_NONE || m_SSLogLevel != SSolver::LOG_OFF)
+            disconnect(reportingSolver, &ExtractorSolver::logOutput, m_ExtractorSolver.data(), &ExtractorSolver::logOutput);
         if(m_SSLogLevel != LOG_OFF && !m_HasSolved)
             emit logOutput(QString("Child solver: %1 did not solve or was aborted").arg(whichSolver(reportingSolver)));
     }
@@ -958,7 +996,7 @@ void addPathToListIfExists(QStringList *list, QString path)
 QStringList StellarSolver::getDefaultIndexFolderPaths()
 {
     QStringList indexFilePaths;
-#if defined(Q_OS_OSX)
+#if defined(Q_OS_MACOS)
     //Mac Default location
     addPathToListIfExists(&indexFilePaths, QDir::homePath() + "/Library/Application Support/Astrometry");
     //Homebrew location
@@ -987,7 +1025,7 @@ bool StellarSolver::appendStarsRAandDEC(QList<FITSImage::Star> &stars)
 //But from what I read, getting the Available RAM is inconsistent and buggy on many systems.
 bool StellarSolver::getAvailableRAM(double &availableRAM, double &totalRAM)
 {
-#if defined(Q_OS_OSX)
+#if defined(Q_OS_MACOS)
     int mib [] = { CTL_HW, HW_MEMSIZE };
     size_t length;
     length = sizeof(int64_t);
@@ -1059,7 +1097,7 @@ bool StellarSolver::enoughRAMisAvailableFor(const QStringList &indexFolders)
         emit logOutput(
             QString("Evaluating Installed RAM for inParallel Option.  Total Size of Index files: %1 GB, Installed RAM: %2 GB, Free RAM: %3 GB").arg(
                 totalSize / bytesInGB).arg(totalRAM / bytesInGB).arg(availableRAM / bytesInGB));
-#if defined(Q_OS_OSX)
+#if defined(Q_OS_MACOS)
         emit logOutput("Note: Free RAM for now is reported as Installed RAM on MacOS until I figure out how to get available RAM");
 #endif
     }
